@@ -2,7 +2,7 @@ import threading
 
 __author__ = 'paoolo'
 
-TIMEOUT = 60
+TIMEOUT = 1.0
 
 
 class FutureObject(object):
